@@ -12,6 +12,12 @@ impl From<error::General> for StreamsonError {
     }
 }
 
+impl From<error::Matcher> for StreamsonError {
+    fn from(_gerror: error::Matcher) -> Self {
+        Self
+    }
+}
+
 /// Python wrapper around matchers
 #[pyclass]
 #[derive(Debug)]
@@ -29,7 +35,9 @@ impl RustMatcher {
     #[staticmethod]
     pub fn simple(path: String) -> PyResult<Self> {
         Ok(Self {
-            inner: matcher::Combinator::new(matcher::Simple::new(path)),
+            inner: matcher::Combinator::new(
+                matcher::Simple::new(&path).map_err(StreamsonError::from)?,
+            ),
         })
     }
 
@@ -84,10 +92,11 @@ impl Streamson {
     /// # Arguments
     /// * `matches` - a list of valid simple matches (e.g. `{"users"}`, `[]{"name"}`, `[0]{}`)
     #[new]
-    pub fn new(matcher: &RustMatcher) -> PyResult<Self> {
-        let handler = Arc::new(Mutex::new(handler::Buffer::new()));
-        let collector =
-            Collector::new().add_matcher(Box::new(matcher.inner.clone()), &[handler.clone()]);
+    pub fn new(matcher: &RustMatcher, show_path: Option<bool>) -> PyResult<Self> {
+        let show_path = show_path.unwrap_or(true);
+        let handler = Arc::new(Mutex::new(handler::Buffer::new().set_show_path(show_path)));
+        let mut collector = Collector::new();
+        collector.add_matcher(Box::new(matcher.inner.clone()), &[handler.clone()]);
         Ok(Self { collector, handler })
     }
 
@@ -107,14 +116,15 @@ impl Streamson {
     ///
     /// # Returns
     /// * `None` - if no data present
-    /// * `Some(<path>, <bytes>)` if there are some data
-    fn pop(&mut self) -> Option<(String, Vec<u8>)> {
+    /// * `Some(<path>, <data_str>)` if there are some data
+    fn pop(&mut self) -> PyResult<Option<(Option<String>, String)>> {
         match self.handler.lock().unwrap().pop() {
-            Some((path, bytes)) => Some((path, bytes.to_vec())),
-            None => None,
+            Some((path, bytes)) => Ok(Some((path, String::from_utf8(bytes)?))),
+            None => Ok(None),
         }
     }
 }
+
 /// This module is a python module implemented in Rust.
 #[pymodule]
 fn streamson(_py: Python, m: &PyModule) -> PyResult<()> {
